@@ -368,11 +368,46 @@ def destroy(account_number,role_to_assume_to_target_account,cloudformation_stack
         except Exception as error:
             traceback.print_tb(error.__traceback__)
             print('attempt to delete ecr repo failed.')
-            raise ValueError(str(error))
 
         # get ECS instance role from CFN output
         ecs_instance_role = search_result_dictionary['ECSInstanceRoleName']
 
+        # get ECS instance profile from CFN output
+        ecs_instance_profile = search_result_dictionary['ECSInstanceProfileName']
+
+        # detach policies from role
+        try:
+            
+            # list all attached role policies
+            response = iam_assumed_client.list_attached_role_policies(
+                    RoleName=ecs_instance_role
+                )
+            print(response)
+            policy_arn_jsons = response['AttachedPolicies']
+
+            # for each policy arn json attached detach it from the role
+            for policy_arn_json in policy_arn_jsons:
+                response = iam_assumed_client.detach_role_policy(
+                    RoleName=ecs_instance_role,
+                    PolicyArn=policy_arn_json['PolicyArn']
+                )
+                print(response)
+
+        except Exception as error:
+            traceback.print_tb(error.__traceback__)
+            print('attempt to detach policy from ecs instance role failed.')
+
+        # remove ECS instance role from instance profile
+        try:
+            response = iam_assumed_client.remove_role_from_instance_profile(
+                InstanceProfileName=ecs_instance_profile,
+                RoleName=ecs_instance_role
+            )
+            print(response)
+        except Exception as error:
+            traceback.print_tb(error.__traceback__)
+            print('attempt to remove ecs instance role from ecs instance profile failed.')
+
         # delete ECS instance role
         try:
             response = iam_assumed_client.delete_role(RoleName=ecs_instance_role)
@@ -380,19 +415,14 @@ def destroy(account_number,role_to_assume_to_target_account,cloudformation_stack
         except Exception as error:
             traceback.print_tb(error.__traceback__)
             print('attempt to delete ecs instance role failed.')
-            raise ValueError(str(error))
-
-        # get ECS instance profile from CFN output
-        ecs_instance_profile = search_result_dictionary['ECSInstanceProfileName']
 
         # delete instance profile
         try:
-            response = iam_assumed_client.delete_repository(InstanceProfileName=ecs_instance_profile)
+            response = iam_assumed_client.delete_instance_profile(InstanceProfileName=ecs_instance_profile)
             print(response)
         except Exception as error:
             traceback.print_tb(error.__traceback__)
             print('attempt to delete ecs instance profile failed.')
-            raise ValueError(str(error))
 
         # delete cloudformation stack
         try:
@@ -401,7 +431,6 @@ def destroy(account_number,role_to_assume_to_target_account,cloudformation_stack
         except Exception as error:
             traceback.print_tb(error.__traceback__)
             print('attempt to delete cloudformation stack failed.')
-            raise ValueError(str(error))
 
     except Exception as error:
         traceback.print_tb(error.__traceback__)
